<%@ Page Language="C#" AutoEventWireup="True" Debug="true" ValidateRequest="false" %>

<%@ Import Namespace="System.IO" %>
<%@ Import Namespace="System.Xml" %>
<%@ Import Namespace="System.Security.Cryptography" %>

<script runat="server">
	//This variable specifies relative path to the folder, where the gallery with uploaded files is located.
	//Do not forget about the slash in the end of the folder name.
	private string galleryPath = "../Gallery/";

	private void Page_Load(System.Object sender, System.EventArgs e)
	{
		//Get the source file. 
		//NOTE: Since each file is uploaded in a separate request (because 
		//FilesPerOnePackageCount param equals to 1), you should work only 
		//with POST fields with index = 1 (such as SourceFile_1, FileName_1, etc).
		HttpPostedFile sourceFile = Request.Files["SourceFile_1"];

		//Verify upload integrity. To do it, get the source file, compute hash value for it,
		//and compare the result with the hash value calculated by Image Uploader.

		//NOTE: In real-life application a single hash method is typically enough.

		byte[] sourceFileBytes = new byte[sourceFile.InputStream.Length];
		sourceFile.InputStream.Read(sourceFileBytes, 0, (int)(sourceFile.InputStream.Length));

		//Get SHA1 Hash.
		string postedSHA1Hash = Request.Form["HashCodeSHA_1"];

		//Make sure that this value is actually uploaded.
		if (postedSHA1Hash != null)
		{
			//Compute SHA1 hash. Since Image Uploader sends the hash value encoded with Base 64 algorithm
			//the result should be also encoded with Base 64.
			SHA1CryptoServiceProvider SHA1 = new SHA1CryptoServiceProvider();
			string actualSHA1Hash = Convert.ToBase64String(SHA1.ComputeHash(sourceFileBytes));

			//If the result differs from the uploaded one, the upload should be interpreted as corrupted.
			if (postedSHA1Hash != actualSHA1Hash)
			{
				Response.StatusCode = 400;
				Response.End();
				return;
			}
		}

		//Get MD5 hash.
		string postedMD5Hash = Request.Form["HashCodeMD5_1"];

		//Make sure that this value is actually uploaded.
		if (postedMD5Hash != null)
		{
			//Compute MD5 hash. Since Image Uploader sends the hash value encoded with Base 64 algorithm
			//the result should be also encoded with Base 64.
			MD5CryptoServiceProvider MD5 = new MD5CryptoServiceProvider();
			string actualMD5Hash = Convert.ToBase64String(MD5.ComputeHash(sourceFileBytes));

			//If the result differs from the uploaded one, the upload should be interpreted as corrupted.
			if (postedMD5Hash != actualMD5Hash)
			{
				Response.StatusCode = 400;
				Response.End();
				return;
			}
		}

		//Get MD2 hash

		//NOTE: MD2 support is not available in standard .NET Framework libraries, so you will have 
		//to use some third party classes to use it. For example you can use the Mono.Security.dll
		//assembly from Mono project (http://www.mono-project.com) which includes the MD2Managed class.
		//Download this assembly and uncomment the code below: 

		//string postedMD2Hash = Request.Form["HashCodeMD2_1"];

		//if (postedMD2Hash != null)
		//{
		//        //Compute MD2 hash. Since Image Uploader sends the hash value encoded with Base 64 algorithm
		//        //the result should be also encoded with Base 64.		
		//        Mono.Security.Cryptography.MD2Managed MD2 =
		//            new Mono.Security.Cryptography.MD2Managed();
		//        string actualMD2Hash = Convert.ToBase64String(MD2.ComputeHash(sourceFileBytes));

		//        //Compute MD5 hash. Since Image Uploader sends the hash value encoded with Base 64 algorithm
		//        //the result should be also encoded with Base 64.
		//        if (postedMD2Hash != actualMD2Hash)
		//        {
		//                Response.StatusCode = 400;
		//                Response.End();
		//                return;
		//        }
		//}

		//If we reach this line, it means that file was not corrupted during upload.
		//In this case we should save it to disk. 

		//Before saving uploaded files let's delete previously uploaded items.
		//
		//In this code sample each file is uploaded with a separate request. It means that this 
		//page will be called for each file individually (rather than once for all files). Therefore
		//we need a way to determine whether this page is called for new upload session or not.
		//
		//To do it we check a PackageIndex POST field which returns a number of the request in the upload session.
		//If it is the very first package we should delete all files we uploaded before. 
		//Otherwise, previously uploaded files belong to the same upload session and we should not delete them.
		int packageIndex = Int32.Parse(Request.Form["PackageIndex"]);

		if (packageIndex == 0)
		{
			//Delete source files.
			DirectoryInfo dir = new DirectoryInfo(Server.MapPath(galleryPath));
			foreach (FileInfo file in dir.GetFiles())
			{
				file.Delete();
			}
		}

		//NOTE: If you do not want to delete previously uploaded files, just 
		//remove or comment out the code above.

		//Save the uploaded file to disk.
		string fileName = GetSafeFileName(sourceFile.FileName);
		sourceFile.SaveAs(Server.MapPath(galleryPath + fileName));
	}

	//This method verifies whether file with such name already exists 
	//and if so, construct safe filename name (to avoid collision).	
	private string GetSafeFileName(string fileName)
	{
		string newFileName = fileName;
		int j = 1;
		while (File.Exists(Server.MapPath(galleryPath + newFileName)))
		{
			newFileName = j + "_" + fileName;
			j++;
		}
		return newFileName;
	}
</script>

