#!/usr/bin/perl

use CGI qw/:standard/;
use File::Spec;
use File::Basename;
use XML::Simple;

#Modify this block, according to your needs.

#This variable specifies relative path to the folder, where the gallery with uploaded files is located.
#Do not forget about the slash in the end of the folder name.
my $galleryPath = "../Gallery/";
my $absGalleryPath;
my $absThumbnailsPath;

sub print_html {
	print "Content-Type: text/html\r\n\r\n";
	print "\r\n";
}

sub save_uploaded_files {
	#Physical path to the gallery folder
	$absGalleryPath = File::Spec->rel2abs($galleryPath);
	$absThumbnailsPath = File::Spec->join($absGalleryPath, "Thumbnails");
	
	#First of all, clear files and data uploaded at previous time.
	
	my $handle;
	
	#Delete source files.
	opendir($handle, $absGalleryPath);
	while (my $fileName = readdir($handle)) {
		my $filePath = File::Spec->join($absGalleryPath, $fileName);
		if (-f $filePath) {
			unlink($filePath);
		}
	}
	closedir($handle);
	
	#Delete thumbnails.
	opendir($handle, $absThumbnailsPath);
	while (my $fileName = readdir($handle)) {
		my $filePath = File::Spec->join($absThumbnailsPath, $fileName);
		if (-f $filePath) {
			unlink($filePath);
		}
	}
	closedir($handle);
	
	#NOTE: If you do not want to delete previously uploaded files, just
	#remove or comment out the code above.
	
	#Create array (for futher saving in XML file) which will keep information about files (image dimensions, description, etc).
	#XML is used solely for brevity. In real-life application most likely you will use database instead.
	my @files;
	
	#Get total number of uploaded files (all files are uploaded in a single package).
	my $fileCount = param("FileCount");
	
	#Iterate through uploaded data and save the original file, thumbnail, and description.
	for (my $i = 1; $i <= $fileCount; $i++){
		#Get source file and save it to disk.
		my $sourceFilePath = param("SourceFile_" . $i);
		my $fileName = get_safe_file_name($sourceFilePath);
		#Copy file to gallery folder
		open(OUT, ">" . File::Spec->join($absGalleryPath, $fileName)); 
		binmode(OUT);  
		while (<$sourceFilePath>) {   
			print OUT $_;   
		}  
		close(OUT);
		       
		#Get first thumbnail (the single thumbnail in this code sample) and save it to disk.
		my $thumbnail1Path = param("Thumbnail1_" . $i);
		#Copy file to thumbnails folder
		open(OUT, ">" . File::Spec->join($absThumbnailsPath, $fileName . ".jpg")); 
		binmode(OUT);  
		while (<$thumbnail1Path>) {   
			print OUT $_;   
		}  
		close(OUT);	
		
		#Save file info.
		push(@files, {name => $fileName, width => param("Width_" . $i), 
			height => param("Height_" . $i), description => param("Description_" . $i)});
	}
	   
	my $descriptions = {file => \@files};
	
	my $descriptionsPath = File::Spec->join($absGalleryPath, "Descriptions.xml");
	
	my $xml = new XML::Simple(NoAttr => 0, RootName => 'files', OutputFile => $descriptionsPath);
	$xml->XMLout($descriptions);
}

#This method verifies whether file with such name already exists 
#and if so, construct safe filename name (to avoid collision).
sub get_safe_file_name {
	my $fileName = basename(shift(@_));
	my $newFileName = $fileName;
	my $j = 1;
	while (-e File::Spec->join($absGalleryPath, $newFileName)) {
		$newFileName = $j . "_" . $fileName;
	}
	return $newFileName;
}

print_html();

save_uploaded_files();
