#!/usr/bin/perl

use CGI qw/:standard/;
use File::Spec;
use File::Basename;
use XML::Simple;
use Digest::SHA1;
use Digest::MD5;
use Digest::MD2;

#Modify this block, according to your needs.

#This variable specifies relative path to the folder, where the gallery with uploaded files is located.
#Do not forget about the slash in the end of the folder name.
my $galleryPath = "../Gallery/";
my $absGalleryPath;
my $absThumbnailsPath;

sub print_success {
	print "Content-Type: text/html\r\n";
	print "Status: 200 OK\r\n\r\n\r\n";
}

sub print_failure {
	print "Content-Type: text/html\r\n";
	print "Status: 400 Bad Request\r\n\r\n\r\n";
}

sub save_uploaded_files {
	#Physical path to the gallery folder
	$absGalleryPath = File::Spec->rel2abs($galleryPath);
	$absThumbnailsPath = File::Spec->join($absGalleryPath, "Thumbnails");
	
	#Get the source file. 
	#NOTE: Since each file is uploaded in a separate request (because 
	#FilesPerOnePackageCount param equals to 1), you should work only 
	#with POST fields with index = 1 (such as SourceFile_1, FileName_1, etc).       
	my $sourceFilePath = param("SourceFile_1");
	
	#Verify upload integrity. To do it, get the source file, compute hash value for it,
	#and compare the result with the hash value calculated by Image Uploader. 
	my @sourceFileBytes = <$sourceFilePath>;
	
	#NOTE: In real-life application a single hash method is typically enough.
	
	#Get SHA1 Hash.
	my $postedSHA1Hash = param("HashCodeSHA_1");
	
	#Check if this value is actually uploaded.
	if ($postedSHA1Hash) {
		#Compute SHA1 hash. Since Image Uploader sends the hash value encoded with Base 64 algorithm
		#the result should be also encoded with Base 64.
		my $sha1 = Digest::SHA1->new;
		$sha1->add(@sourceFileBytes);
		my $actualSHA1Hash = $sha1->b64digest . "=";
		
		print $postedSHA1Hash . $actualSHA1Hash;
		
		#If the result differs from the uploaded one, the upload should be interpreted as corrupted.
		if (not ($postedSHA1Hash eq $actualSHA1Hash)) {
			print_failure();
			return;
		}
	}
	
	#Get MD5 hash.
	my $postedMD5Hash = param("HashCodeMD5_1");
	
	#Check if this value is actually uploaded.
	if ($postedMD5Hash) {
		#Compute MD5 hash. Since Image Uploader sends the hash value encoded with Base 64 algorithm
		#the result should be also encoded with Base 64.
		my $md5 = Digest::MD5->new;
		$md5->add(@sourceFileBytes);
		my $actualMD5Hash = $md5->b64digest . "==";
		
		print $postedMD5Hash . $actualMD5Hash;
		
		#If the result differs from the uploaded one, the upload should be interpreted as corrupted.
		if (not ($postedMD5Hash eq $actualMD5Hash)) {
			print_failure();
			return;
		}
	}
	
# 	#Get MD2 hash
# 	my $postedMD2Hash = param("HashCodeMD2_1");

# 	#Check if this value is actually uploaded. 
# 	if ($postedMD2Hash) {
# 		#Compute MD2 hash. Since Image Uploader sends the hash value encoded with Base 64 algorithm
# 		#the result should be also encoded with Base 64.		
# 		my $md2 = Digest::MD2->new;
# 		$md2->add(@sourceFileBytes);
# 		my $actualMD2Hash = $md2->b64digest . "==";

# 		print $postedMD2Hash . $actualMD2Hash;

# 		if (not ($postedMD2Hash eq $actualMD2Hash)) {
# 			print_failure();
# 			return;
# 		}
# 	}
	
	#If we reach this line, it means that file was not corrupted during upload. 
	#In this case we should save it to disk. 
	
	#Before saving uploaded files let's delete previously uploaded items. 
	
	#In this code sample each file is uploaded with a separate request. It means that this 
	#page will be called for each file individually (rather than once for all files). Therefore
	#we need a way to determine whether this page is called for new upload session or not.
	
	#To do it we check a PackageIndex POST field which returns a number of the request in the upload session.
	#If it is the very first package we should delete all files we uploaded before. 
	#Otherwise, previously uploaded files belong to the same upload session and we should not delete them. 	        
	my $packageIndex = param("PackageIndex");
	
	if ($packageIndex == 0) {
		my $handle;
		
		#Delete source files.
		opendir($handle, $absGalleryPath);
		while (my $fileName = readdir($handle)) {
			my $filePath = File::Spec->join($absGalleryPath, $fileName);
			if (-f $filePath) {
				unlink($filePath);
			}
		}
		closedir($handle);
	}
	
	#NOTE: If you do not want to delete previously uploaded files, just 
	#remove or comment out the code above.
		
	#Save the uploaded file to disk.
	my $fileName = get_safe_file_name($sourceFilePath);
	#Copy file to gallery folder
	open(OUT, ">" . File::Spec->join($absGalleryPath, $fileName)); 
	binmode(OUT);
	print OUT @sourceFileBytes;
	close(OUT);
	
	print_success
}

#This method verifies whether file with such name already exists 
#and if so, construct safe filename name (to avoid collision).
sub get_safe_file_name {
	my $fileName = basename(shift(@_));	
	my $newFileName = $fileName;
	my $j = 1;
	while (-e File::Spec->join($absGalleryPath, $newFileName)) {
		$newFileName = $j . "_" . $fileName;
	}
	return $newFileName;
}

save_uploaded_files();
