#!/usr/bin/perl

use File::Spec;
use XML::Simple;
use Data::Dumper;
use URI::Escape;
use HTML::Entities;

#This variable specifies relative path to the folder, where the gallery with uploaded files is located.
#Do not forget about the slash in the end of the folder name.
my $galleryPath = "../Gallery/";
  
my $HTML_TEMPLATE = <<HTMLEND;
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
	<title>Aurigma Image Uploader - Uploaded Files</title>
	<link href="style.css" type="text/css" rel="stylesheet" />
</head>
<body>
	<p>
		<a href="index.pl">Upload New Files</a>
	</p>
    <fieldset>
    <legend>Note</legend>
        Watermark is applied on large thumbnails only. So to see it, click a small preview below. 
    </fieldset>	
	<table width="100%%">
		%s
	</table>
</body>
</html>
HTMLEND

my $FILE_INFO_TEMPLATE = <<HTMLEND;
<td>
<a href="%s" target="_blank">
<img src="%s" alt="%s" />
</a>
<br />
<br />
<b>Name:</b>
%s
<br />
<b>Dimensions:</b>
%s
x
%s
<br />
<b>Author:</b>
%s
</td>
HTMLEND

sub print_html {
	print "Content-Type: text/html\r\n\r\n";
	
	#Physical path to the gallery folder
	my $absGalleryPath = File::Spec->rel2abs($galleryPath);
	
	my $descriptionsPath = File::Spec->join($absGalleryPath, "Descriptions.xml");
	
	my $xml = new XML::Simple(KeyAttr => [], ForceArray => 1);
	my $descriptions = $xml->XMLin($descriptionsPath);
	
	my $colCount = 4;
	my $rows = "";
	my $i = 0;
	
	foreach my $file (@{$descriptions->{file}}) {
		if ($i % $colCount == 0) {
			$rows .= "<tr>";
		}
		
		$rows .= sprintf($FILE_INFO_TEMPLATE, $galleryPath . encode_file_name($file->{name}),
			$galleryPath . "Thumbnails/" . encode_file_name($file->{name}) . ".jpg",
			encode_entities($file->{name}),
			encode_entities($file->{name}),
			encode_entities($file->{width}),
			encode_entities($file->{height}),
			encode_entities($file->{author}));
		
		if (($i + 1) % $colCount == 0) {
			$rows .= "</tr>"
		}
		
		$i++;
	}
		
	if ($i % $colCount != 0) {
		$rows .= "</tr>"
	}
		
	printf $HTML_TEMPLATE, $rows;
}

sub encode_file_name {
	return 	uri_escape(shift(@_));
}

print_html();