#!/usr/local/bin/python

import cgi
import cgitb; cgitb.enable()
import os
import sha
import md5
import base64

try: # Windows needs stdio set for binary mode.
	import msvcrt
	msvcrt.setmode ( 0, os.O_BINARY ) # stdin  = 0
	msvcrt.setmode ( 1, os.O_BINARY ) # stdout = 1
except ImportError:
	pass

#This variable specifies relative path to the folder, where the gallery with uploaded files is located.
#Do not forget about the slash in the end of the folder name.
galleryPath = "../Gallery/"

def print_success ():
	print "Content-Type: text/html"
	print "Status: 200 OK"	
	print
	print

def print_failure ():
	print "Content-Type: text/html"
	print "Status: 400 Bad Request"
	print
	print	

def save_uploaded_files ():
	absGalleryPath = os.path.abspath( galleryPath )
	
	form = cgi.FieldStorage()
	
	#Get the source file. 
	#NOTE: Since each file is uploaded in a separate request (because 
	#FilesPerOnePackageCount param equals to 1), you should work only 
	#with POST fields with index = 1 (such as SourceFile_1, FileName_1, etc).       
	sourceFile = form["SourceFile_1"]
	if not sourceFile.file:	
		print_failure()
		return
	
	#Verify upload integrity. To do it, get the source file, compute hash value for it,
	#and compare the result with the hash value calculated by Image Uploader. 
	
	#NOTE: In real-life application a single hash method is typically enough.
	
	sourceFileBytes = sourceFile.file.read()

	#Get SHA1 Hash.
	postedSHA1Hash = form.getfirst( "HashCodeSHA_1", "" )

	#Check if this value is actually uploaded.
	if postedSHA1Hash <> "":
		#Compute SHA1 hash. Since Image Uploader sends the hash value encoded with Base 64 algorithm
		#the result should be also encoded with Base 64.
		shahash = sha.new( sourceFileBytes )
		actualSHA1Hash = base64.encodestring( shahash.digest() )
		#Remove newline ('\n') character in the end of string added by base64.encodestring function
		actualSHA1Hash = actualSHA1Hash[0 : len(actualSHA1Hash) - 1]
	
		#If the result differs from the uploaded one, the upload should be interpreted as corrupted.
		if postedSHA1Hash <> actualSHA1Hash:
			print "SHA! not equalt, but they are " + postedSHA1Hash + "AND " + actualSHA1Hash
			print_failure()
			return

	
	#Get MD5 hash.
	postedMD5Hash = form.getfirst( "HashCodeMD5_1", "" )	
	
	#Check if this value is actually uploaded. 
	if postedMD5Hash <> "":
		#Compute MD5 hash. Since Image Uploader sends the hash value encoded with Base 64 algorithm
		#the result should be also encoded with Base 64.
		md5hash = md5.new( sourceFileBytes )
		actualMD5Hash = base64.encodestring( md5hash.digest() )
		#Remove newline ('\n') character in the end of string added by base64.encodestring function
		actualMD5Hash = actualMD5Hash[0 : len(actualMD5Hash) - 1]
		
		#If the result differs from the uploaded one, the upload should be interpreted as corrupted.
		if postedMD5Hash <> actualMD5Hash:
			print_failure()
			return
	
	#If we reach this line, it means that file was not corrupted during upload. 
	#In this case we should save it to disk. 
	#
	#Before saving uploaded files let's delete previously uploaded items. 
	#
	#In this code sample each file is uploaded with a separate request. It means that this 
	#page will be called for each file individually (rather than once for all files). Therefore
	#we need a way to determine whether this page is called for new upload session or not.
	#
	#To do it we check a PackageIndex POST field which returns a number of the request in the upload session.
	#If it is the very first package we should delete all files and thumbnails we uploaded before. 
	#Otherwise, previously uploaded files belong to the same upload session and we should not delete them. 	        
	packageIndex = int( form.getfirst( "PackageIndex", "0" ) );
		
	if packageIndex == 0:
		#Delete source files.		
		for fileName in os.listdir( absGalleryPath ):	
			filePath = os.path.join( absGalleryPath, fileName )
			if not os.path.isdir( filePath ):
				os.remove( filePath )
	
	#NOTE: If you do not want to delete previously uploaded files, just 
	#remove or comment out the code above.
	
	#Save the uploaded file to disk.
	fileName = get_safe_file_name( sourceFile.filename )			
	f = open ( os.path.join( absGalleryPath, fileName ), 'wb' )
	f.write( sourceFileBytes )
	f.close()

	print_success()
	
#This method verifies whether file with such name already exists 
#and if so, construct safe filename name (to avoid collision).
def get_safe_file_name( fileName ):
	fileName = os.path.basename( fileName )
	newFileName = fileName
	j = 1
	while os.path.exists( os.path.join( os.path.abspath( galleryPath ), newFileName ) ):
		newFileName = str( j ) + "_" + fileName
		j = j + 1
	return newFileName

save_uploaded_files()