require 'cgi'
require 'rexml/document'
require 'digest/sha1'
require 'digest/md5'
require 'base64'

#This variable specifies relative path to the folder, where the gallery with uploaded files is located.
#Do not forget about the slash in the end of the folder name.
$galleryPath = "../Gallery/"

def print_success()
	print "Content-Type: text/html\r\n"
	print "Status: 200 OK\r\n"
	print "\r\n"
	print "\r\n"
end

def print_failure()
	print "Content-Type: text/html\r\n"
	print "Status: 400 Bad Request\r\n"
	print "\r\n"
	print "\r\n"
end

def save_uploaded_files()
	$absGalleryPath = File.expand_path($galleryPath)
	absThumbnailsPath = File.join($absGalleryPath, "Thumbnails")

	cgi = CGI.new()

	#Get the source file. 
	#NOTE: Since each file is uploaded in a separate request (because 
	#FilesPerOnePackageCount param equals to 1), you should work only 
	#with POST fields with index = 1 (such as SourceFile_1, FileName_1, etc).         
	sourceFile = cgi.params["SourceFile_1"].first

	#Verify upload integrity. To do it, get the source file, compute hash value for it,
	#and compare the result with the hash value calculated by Image Uploader. 

	#NOTE: In real-life application a single hash method is typically enough.

	sourceFileBytes = sourceFile.read

	#Get SHA1 Hash.

	#Check if this value is actually uploaded.
	if cgi.params['HashCodeSHA_1'] then
		postedSHA1Hash = cgi.params['HashCodeSHA_1'].first.read

		#Compute SHA1 hash. Since Image Uploader sends the hash value encoded with Base 64 algorithm
		#the result should be also encoded with Base 64.

		actualSHA1Hash = Base64.encode64(Digest::SHA1.new(sourceFileBytes).digest).strip

		#If the result differs from the uploaded one, the upload should be interpreted as corrupted.
		if (postedSHA1Hash != actualSHA1Hash)
			print_failure()
			return
		end
	end

	#Get MD5 hash.

	#Check if this value is actually uploaded.
	if cgi.params['HashCodeMD5_1'] then
		postedMD5Hash = cgi.params['HashCodeMD5_1'].first.read

		#Compute MD5 hash. Since Image Uploader sends the hash value encoded with Base 64 algorithm
		#the result should be also encoded with Base 64.
		actualMD5Hash = Base64.encode64(Digest::MD5.new(sourceFileBytes).digest).strip

		#If the result differs from the uploaded one, the upload should be interpreted as corrupted.
		if (postedMD5Hash != actualMD5Hash)
			print_failure()
			return
		end
	end

	#If we reach this line, it means that file was not corrupted during upload. 
	#In this case we should save it to disk. 


	#Before saving uploaded files let's delete previously uploaded items. 
	#
	#In this code sample each file is uploaded with a separate request. It means that this 
	#page will be called for each file individually (rather than once for all files). Therefore
	#we need a way to determine whether this page is called for new upload session or not.
	#
	#To do it we check a PackageIndex POST field which returns a number of the request in the upload session.
	#If it is the very first package we should delete all files we uploaded before. 
	#Otherwise, previously uploaded files belong to the same upload session and we should not delete them. 	        

	packageIndex = Integer(cgi.params['PackageIndex'].first.read)

	if packageIndex == 0 then
		#Delete source files.		
		Dir.foreach($absGalleryPath) {|fileName|
			filePath = File.join($absGalleryPath, fileName)
			if File.ftype(filePath) == "file" then
				File.delete(filePath)
			end
		}
	end

	#NOTE: If you do not want to delete previously uploaded files, just 
	#remove or comment out the code above.

	#Save the uploaded file to disk.
	fileName = get_safe_file_name(sourceFile.original_filename)
	sourceFileTargetPath = File.join($absGalleryPath, fileName)
	file = File.open(sourceFileTargetPath.untaint, 'wb') 
	file << sourceFileBytes
	file.close

	print_success()
end

def get_safe_file_name(fileName)
	newFileName = File.basename(fileName)
	j = 1
	while FileTest.exist?(File.join($absGalleryPath, newFileName))
		newFileName = j.to_s + "_" + fileName
	end
	return newFileName
end

save_uploaded_files()